@@ -8,9 +8,9 @@ $footerBG = get_field('footer_background', 'options')['url'];
 ?>
 </main>
 <?php if($video) { ?>
-<video autoplay="autoplay" muted loop class="background-video">
-    <source src="<?= $video['url']; ?>" type="video/mp4">
-</video>
+    <video autoplay="autoplay" muted loop class="background-video">
+        <source src="<?= $video['url']; ?>" type="video/mp4">
+    </video>
 <?php } ?>
 <section class="da_panel">
     <div class="da_panel__content">
@@ -28,91 +28,80 @@ $footerBG = get_field('footer_background', 'options')['url'];
     </div>
 </section>
 <?php
-    $activatePopup = get_field('activate_popup', 'options');
+$activatePopup = get_field('activate_popup', 'options');
 
-    if ($activatePopup && is_front_page()) {
-?>
+if ($activatePopup && is_front_page()) {
+    ?>
     <section class="da_panel_product">
         <div class="da_panel_product__content ">
             <a class="btn btn-primary da_btn_product" href="/"><span>X</span></a>
             <?php
-                $popupContent = get_field('popup_content', 'options');
+            $popupContent = get_field('popup_content', 'options');
             ?>
             <div class="popup-inner">
                 <?= $popupContent ?>
             </div>
         </div>
     </section>
-<?php
-    }
+    <?php
+}
 ?>
 <section class="footer-quick-access">
-    <div class="container-fluid">
+    <div class="container">
         <div class="row">
-            <div class="col-lg-5 quick-left">
-                <div class="container">
-                    <div class="row">
-                        <div class="col-md-4">
-                            <?php if (has_nav_menu('quick_left')) {
-                               wp_nav_menu(['theme_location' => 'quick_left','menu_class' => '']);
-                            }
-                            ?>
-                        </div>
-                        <div class="col-md-4">
-                            <?php if (has_nav_menu('quick_middle')) { 
-                                wp_nav_menu(['theme_location' => 'quick_middle','menu_class' => '']);
-                            }
-                            ?>
-                        </div>
-                        <div class="col-md-4">
-                            <?php if (has_nav_menu('quick_right')) {
-                                wp_nav_menu(['theme_location' => 'quick_right','menu_class' => '']);
-                            }
-                            ?>
-                        </div>
+            <div class="order-lg-1 col-lg-7 col-xl-5 quick-left">
+                <div class="row">
+                    <div class="col-md-4">
+                        <?php if (has_nav_menu('quick_left')) {
+                            wp_nav_menu(['theme_location' => 'quick_left','menu_class' => '']);
+                        }
+                        ?>
+                    </div>
+                    <div class="col-md-4">
+                        <?php if (has_nav_menu('quick_middle')) {
+                            wp_nav_menu(['theme_location' => 'quick_middle','menu_class' => '']);
+                        }
+                        ?>
+                    </div>
+                    <div class="col-md-4">
+                        <?php if (has_nav_menu('quick_right')) {
+                            wp_nav_menu(['theme_location' => 'quick_right','menu_class' => '']);
+                        }
+                        ?>
                     </div>
                 </div>
             </div>
-            <div class="col-lg-2 quick-middle">
-            <?php
-            if (have_rows('social_media_channels', 'option')) { ?>
-                <ul class="social navigation">
-                    <?php
-                    while (have_rows('social_media_channels', 'option')) {
-                        the_row(); ?>
-                        <li><a href="<?php the_sub_field('full_url'); ?>" target="_blank" rel="noopener"><i class="<?php the_sub_field('fa5_icon_class'); ?>"></i></a></li>
-                    <?php } ?>
-                </ul>
-            <?php } ?>
+            <div class="order-lg-3 col-lg-12 order-xl-2 col-xl-2 quick-middle">
+                <?php
+                if (have_rows('social_media_channels', 'option')) { ?>
+                    <ul class="social navigation">
+                        <?php
+                        while (have_rows('social_media_channels', 'option')) {
+                            the_row(); ?>
+                            <li><a href="<?php the_sub_field('full_url'); ?>" target="_blank" rel="noopener"><i class="<?php the_sub_field('fa5_icon_class'); ?>"></i></a></li>
+                        <?php } ?>
+                    </ul>
+                <?php } ?>
             </div>
-            <div class="col-lg-5 quick-right">
-                <p>At Pilgrims gin we have lots of exclusive promotions and product launches, read our privacy policy here before signing up and then get all the latest from us.</p>
-                <br>      
-                <form
-                    action=""
-                    method="get" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate"
-                    target="_blank" novalidate>
+            <div class="order-lg-2 col-lg-5 col-xl-5 quick-right">
+                <p class="footer-description">At Pilgrims gin we have lots of exclusive promotions and product launches, read our <a href="<?= home_url( '/privacy-policy' ); ?>">privacy policy here</a> before signing up and then get all the latest from us.</p>
+                <form action="" method="get" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank" novalidate>
                     <label for="newsletter-signup">
                         Sign up to our newsletter:
                     </label>
                     <div class="form-wrapper">
-                        <input type="email" value="" name="EMAIL" class="email" id="mce-EMAIL"
-                            placeholder="Please enter your email address..." required>
-                        <!-- real people should not fill this in and expect good things - do not remove this or risk form bot signups-->
-                        <div style="position: absolute; left: -5000px;" aria-hidden="true"><input type="text"
-                                name="b_d1b3516dea2ce7b5f404ef446_c77a838f81" tabindex="-1" value=""></div>
-                        <button type="submit" value="Subscribe" name="subscribe" id="mc-embedded-subscribe"
-                            class="btn btn-secondary btn-compact"><span>GO</span></button>
+                        <input type="email" value="" name="EMAIL" class="email" id="mce-EMAIL" placeholder="Enter your email address" required>
+                        <div style="position: absolute; left: -5000px;" aria-hidden="true"><input type="text" name="b_d1b3516dea2ce7b5f404ef446_c77a838f81" tabindex="-1" value=""></div>
+                        <button type="submit" value="Subscribe" name="subscribe" id="mc-embedded-subscribe">GO</button>
                     </div>
                 </form>
-                <div id="mc-embedded-subscribe-mce-responses">
-                </div>
+                <div id="mc-embedded-subscribe-mce-responses"></div>
             </div>
         </div>
     </div>
 </section>
 <footer class="site-footer" style="background-image:url('<?= $footerBG; ?>')">
-    <div class="container-fluid">
+    <div class="container">
         <div class="row">
             <div class="col-lg-2 offset-lg-5 text-center">
                 <img class="brand footer-logo" src="<?= $logo; ?>" alt="<?php bloginfo('name'); ?>" />
@@ -121,11 +110,11 @@ $footerBG = get_field('footer_background', 'options')['url'];
                 <div class="payment-row row">
                     <div class="col">
                         <img class="img-fluid" src="<?= $paymentCards['url']; ?>"
-                            alt="<?= $paymentCards['title']; ?>" />
+                             alt="<?= $paymentCards['title']; ?>" />
                     </div>
                     <div class="col col-lg-5">
                         <img class="img-fluid" src="<?= $paymentProcessLogo['url']; ?>"
-                            alt="<?= $paymentProcessLogo['title']; ?>" />
+                             alt="<?= $paymentProcessLogo['title']; ?>" />
                     </div>
                 </div>
             </div>
@@ -141,7 +130,7 @@ $footerBG = get_field('footer_background', 'options')['url'];
             </div>
 
             <div class="credit col-lg-5 col-md-5">
-                <p><span>Website Powered by </span><?= do_shortcode('[blue2_logo type="light"]'); ?></p>
+                <div class="website-by"><span>Website by</span><?= do_shortcode('[blue2_logo type="light"]'); ?></div>
             </div>
 
             <div class="copyright col-md-12 d-lg-none text-center">
